# CACE format description

This pages introduces you into the characterization file syntax and the version 4.0 schematic description.

```{toctree}
:glob:
:maxdepth: 2

format_description
schematic_description
```
